"""Knoc worker for Hatchet.
It reads its config from environment variables, a, .env file or yaml file,
connects to the Hatcher server using the JWT token in the config,
and executes the tasks and workflows orders.
"""

import sys
from argparse import ArgumentParser

from knoc.hatchet_client import hatchet
from knoc.workflows.splynx import import_splynx_customers
from knoc.workflows.foo import foo_task
from knoc import __version__


def main() -> None:
    parser = ArgumentParser("Knoc worker", description=__doc__)
    parser.add_argument(
        "-v", "--version", action="store_true", help="Print knoc version and exits"
    )
    args = parser.parse_args()
    if args.version:
        print(__version__)
        sys.exit()
    worker = hatchet.worker(
        "knoc-worker",
        workflows=[import_splynx_customers, foo_task],
        labels={"version": __version__},
    )
    worker.start()


if __name__ == "__main__":
    main()
