from hatchet_sdk import Context, EmptyModel

try:
    import pandas as pd  # type: ignore
except ImportError:
    pd = None

from knoc import __version__
from knoc.settings import settings
from knoc.hatchet_client import hatchet
from knoc.ksplynx import splynx_api, SplynxCustomerModel, KSplynxError


@hatchet.task(name="ImportSplynxCustomers", version=__version__)
async def import_splynx_customers(
    input: EmptyModel = EmptyModel(),
    ctx: Context | None = None,
    check_type=False,
):
    if pd is None:
        raise KSplynxError("Pandas is not installed")
    await splynx_api.login()
    resp = await splynx_api.get("admin/customers/customer")
    # await splynx_api.logout()
    resp_json = resp.json()
    customers_json = splynx_api.expand_splynx_aa(resp_json)
    # customers = SplynxCustomersModel.model_validate_json(resp.content)

    if check_type:
        customers = {c["id"]: SplynxCustomerModel.model_validate(c) for c in resp_json}
        assert isinstance(customers, SplynxCustomerModel)

    df = pd.DataFrame.from_dict(customers_json)  # type: ignore
    df.to_feather(settings.data_path / "customers.feather")


# import_splynx_wf.add_task(foo_task.to_task())
